@@ -73,6 +73,7 @@ MOBILE_NUMBER = "mobile_no"
 MODIFIED = "modified"
 MORNING = "morning"
 NAIVE = "NAIVE"
+NCD = "NCD"
 NEG = "NEG"
 NEVER = "NEVER"
 NEW = "New"
@@ -162,3 +163,15 @@ WARN = "warn"
 WEEKDAYS = "weekdays"
 WEEKENDS = "weekends"
 YES = "Yes"
+
+
+FUTURE_DATE = "future_date"
+LAST_WEEK = "last_week"
+NEXT_WEEK = "next_week"
+NOT_NULL = "not_null"
+IS_NULL = "is_null"
+PAST_DATE = "past_date"
+THIS_WEEK = "this_week"
+TODAY = "today"
+TOMORROW = "tomorrow"
+YESTERDAY = "yesterday"
